# FILE EXTENSION
DOCX_FILE_EXTENSION = ".docx"
JSON_FILE_EXTENSION = ".json"
PDF_FILE_EXTENSION = ".pdf"
TXT_FILE_EXTENSION = ".txt"

# ENCODING
UTF_8 = "utf-8"

# PARSING
PUNCTUATION = "—"  # holds punctuation characters that string.punctuation does not include.
